@@ -54,7 +54,7 @@ AWSAddress = collections.namedtuple('AWSAddress', 'name publicdns privateip shar
 #  action is the deferred action needed, such as "deploy", "security-updates", etc.
 #  region is aws region
 @task
-def set_hosts(type,primary=None,appname=None,action=None,region=None,shard=all):
+def set_hosts(type,primary=None,appname=None,action=None,region=None,shard='all'):
     if appname is None:
         local('echo "ERROR: appname option is not set"')
     if region is None:
